/*
 * Copyright (C) 2013-2024 The JavaParser Team.
 *
 * This file is part of JavaParser.
 *
 * JavaParser can be used either under the terms of
 * a) the GNU Lesser General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 * b) the terms of the Apache License
 *
 * You should have received a copy of both licenses in LICENCE.LGPL and
 * LICENCE.APACHE. Please refer to those files for details.
 *
 * JavaParser is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 */

package com.github.javaparser.symbolsolver;

import org.junit.jupiter.api.Test;

import com.github.javaparser.JavaParser;
import com.github.javaparser.JavaParserAdapter;
import com.github.javaparser.ParserConfiguration;
import com.github.javaparser.ast.CompilationUnit;
import com.github.javaparser.ast.expr.MethodCallExpr;
import com.github.javaparser.symbolsolver.resolution.AbstractResolutionTest;

public class Issue4284Test extends AbstractResolutionTest {

	@Test
	void test() {

		String code =
				"public class SampleCode {\n"
				+ "    public static void main(String... args) {\n"
				+ "        char ch = args[0].charAt(0);\n"
				+ "        int result = switch (ch) {\n"
				+ "            default -> System.out.println(ch);\n"
				+ "        };\n"
				+ "    }\n"
				+ "}";

		ParserConfiguration parserConfiguration = new ParserConfiguration()
				.setLanguageLevel(ParserConfiguration.LanguageLevel.JAVA_17)
				.setSymbolResolver(symbolResolver(defaultTypeSolver()));

		CompilationUnit cu = JavaParserAdapter.of(new JavaParser(parserConfiguration)).parse(code);

		cu.findAll(MethodCallExpr.class).forEach(MethodCallExpr::resolve);

	}

}
